/*
 * MINIGUI - Harbour Win32 GUI library
 *
 * Copyright 2012 Janusz Pora <januszpora@onet.eu>
 *
 * 2014: Modified by Andrey Verchenko <verchenkoag@gmail.com>. Dmitrov, Russia
 *
*/

#include "minigui.ch"

// store config file to current folder
#define INI_FILE_WIN_CFG  ChangeFileExt( Application.ExeName, ".cnfg" ) 
// OR store config file to temporary folder
//#define INI_FILE_WIN_CFG  GetTempFolder() + "\" + cFileNoPath( ChangeFileExt( Application.ExeName, ".config" ) )

/////////////////////////////////////////////////////////////////////
Function IniFileYes()
   Local aDim, cText, cPathFileConfig

   cPathFileConfig := INI_FILE_WIN_CFG 

   IF ! File( cPathFileConfig )
      aDim := MsgAbout(.F.)
      cText := "[Information]" + CRLF
      cText += "Program   = " + aDim[1] + aDim[2] + CRLF
      cText += "Copyright = " + aDim[3] + CRLF
      cText += "ExeName   = " + Application.ExeName + CRLF
      cText += "Operating System = " + Os() + CRLF
      cText += "Developed in   = " + MiniGUIVersion() + CRLF
      cText += "xBase Compiler = " + Version() + CRLF
      cText += "C Compiler     = " + Hb_Compiler() + CRLF
      cText += CRLF + CRLF
      HB_MemoWrit( cPathFileConfig, cText )
   ENDIF

Return Nil

/////////////////////////////////////////////////////////////////////
Function IniGetPosWindow( FormName, cProgName )
   Local cSection, actpos := {0,0,0,0}
   Local col , row , width , height
   Local cPathFileConfig, aRet

   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")

   cPathFileConfig := INI_FILE_WIN_CFG 

   GetWindowRect( GetFormHandle( FormName ), actpos )
   cSection := FormName

   IF FILE( cPathFileConfig )
      col    := VAL( GetIni( cSection , "col"    , "0", cPathFileConfig ) )
      row    := VAL( GetIni( cSection , "row"    , "0", cPathFileConfig ) )
      width  := VAL( GetIni( cSection , "width"  , "0", cPathFileConfig ) )
      height := VAL( GetIni( cSection , "height" , "0", cPathFileConfig ) )

      col    := IFNIL( col, actpos[1], col )
      row    := IFNIL( row, actpos[2], row )
      width  := IFNIL( width, actpos[3] - actpos[1], width )
      height := IFNIL( height, actpos[4] - actpos[2], height )
      // If there are no sections, ie Variables are 0
      IF width > 0 .AND. height > 0
         MoveWindow( GetFormHandle( FormName ) , col , row , width , height , .t. )
         aRet := {width, height } 
      ELSE
         aRet := {}
      ENDIF
   ENDIF 

Return aRet

/////////////////////////////////////////////////////////////////////
Function IniSetPosWindow( FormName, cProgName )
   Local cSection, actpos := {0,0,0,0}
   Local col , row , width , height
   Local cPathFileConfig

   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")

   cPathFileConfig := INI_FILE_WIN_CFG 

   GetWindowRect( GetFormHandle( FormName ), actpos )
   cSection := FormName

   col    := actpos[1]
   row    := actpos[2]
   width  := actpos[3] - actpos[1]
   height := actpos[4] - actpos[2]

   WriteIni( cSection, "TitleWin" , cProgName       , cPathFileConfig )
   WriteIni( cSection, "col"      , HB_NToS(col)    , cPathFileConfig )
   WriteIni( cSection, "row"      , HB_NToS(row)    , cPathFileConfig )
   WriteIni( cSection, "width"    , HB_NToS(width)  , cPathFileConfig )
   WriteIni( cSection, "height"   , HB_NToS(height) , cPathFileConfig )

Return Nil

/////////////////////////////////////////////////////////////////////
//     
Function IniGetLangProg(FormName, cProgName, cProgSection)
   Local cSection, nVal, cFileIni := INI_FILE_WIN_CFG
   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")
   Default cProgSection := ""
   cSection := FormName + "/" + cProgSection

   nVal := VAL( GetIni( cSection , "LangProg"  , "2" , cFileIni) ) 

Return nVal

/////////////////////////////////////////////////////////////////////
//     
Function IniSetLangProg(FormName, cProgName, cProgSection, nVal )
   Local cSection, cText, cFileIni := INI_FILE_WIN_CFG
   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")
   Default cProgSection := ""
   cSection := FormName + "/" + cProgSection

   cText := "1-Rus;2-Eng"
   WriteIni( cSection, "LangProg" , HB_NToS(nVal) , cFileIni ) 
   WriteIni( cSection, "LangInfo" , cText         , cFileIni )  

Return Nil

/////////////////////////////////////////////////////////////////////
//    
Function IniGetFilesCnf(FormName, cProgName, cProgSection)
   Local cSection, aDim[10]
   Local cFileIni := INI_FILE_WIN_CFG
   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")
   Default cProgSection := ""
   cSection := FormName + "/" + cProgSection

   aDim[1] := GetIni( cSection, "Path1"       , "" , cFileIni)                         //    1
   aDim[2] := GetIni( cSection, "Path2"       , "" , cFileIni)                         //    2
   aDim[3] := GetIni( cSection, "FileProject" , "" , cFileIni)                         //    
   aDim[4] := if( "F" $ upper(GetIni( cSection,"lCheckPrg" , .F. , cFileIni )),.f.,.t.)//  .prg 
   aDim[5] := if( "F" $ upper(GetIni( cSection,"lCheckCh"  , .F. , cFileIni )),.f.,.t.)//  .ch  
   aDim[6] := if( "F" $ upper(GetIni( cSection,"lCheckC"   , .F. , cFileIni )),.f.,.t.)//  .c   
   aDim[7] := if( "F" $ upper(GetIni( cSection,"lCheckRc"  , .F. , cFileIni )),.f.,.t.)//  .rc  
   aDim[8] := if( "F" $ upper(GetIni( cSection,"lCheckLib" , .F. , cFileIni )),.f.,.t.)//  .lib 
   aDim[9] := if( "F" $ upper(GetIni( cSection,"lCheckBak" , .F. , cFileIni )),.f.,.t.)//  .bak 
   aDim[10] := if( "F" $ upper(GetIni( cSection,"lCheckDbf" , .F. , cFileIni )),.f.,.t.)//  .dbf 

Return aDim

/////////////////////////////////////////////////////////////////////
//    
Function IniSetFilesCnf(FormName, cProgName, cProgSection, aDim)
   Local lYes, cSection, cFileIni := INI_FILE_WIN_CFG
   Default FormName := _HMG_ThisFormName
   Default cProgName := GetProperty(FormName, "Title")
   Default cProgSection := ""
   cSection := FormName + "/" + cProgSection

   lYes := IsINISection(cFileIni, cSection) //    
   WriteIni( cSection, "TitleWin"     , cProgName            , cFileIni )  
   WriteIni( cSection, "DateEdit"     , DTOC(DATE())         , cFileIni )  
   WriteIni( cSection, "Path1"        , aDim[1]              , cFileIni ) //    1 
   WriteIni( cSection, "Path2"        , aDim[2]              , cFileIni ) //    2 
   WriteIni( cSection, "FileProject"  , aDim[3]              , cFileIni ) //     
   WriteIni( cSection, "lCheckPrg"    , IIF(aDim[4],"T","F") , cFileIni ) //  .prg 
   WriteIni( cSection, "lCheckCh"     , IIF(aDim[5],"T","F") , cFileIni ) //  .ch  
   WriteIni( cSection, "lCheckC"      , IIF(aDim[6],"T","F") , cFileIni ) //  .c   
   WriteIni( cSection, "lCheckRc"     , IIF(aDim[7],"T","F") , cFileIni ) //  .rc  
   WriteIni( cSection, "lCheckLib"    , IIF(aDim[8],"T","F") , cFileIni ) //  .lib
   WriteIni( cSection, "lCheckBak"    , IIF(aDim[9],"T","F") , cFileIni ) //  .bak
   WriteIni( cSection, "lCheckDbf"    , IIF(aDim[10],"T","F"), cFileIni ) //  .dbf

Return Nil

*--------------------------------------------------------*
STATIC Function GetIni( cSection, cEntry, cDefault, cFile )
RETURN GetPrivateProfileString(cSection, cEntry, cDefault, cFile )
*--------------------------------------------------------*
STATIC Function WriteIni( cSection, cEntry, cValue, cFile )
RETURN( WritePrivateProfileString( cSection, cEntry, cValue, cFile ) )
*--------------------------------------------------------*
STATIC Function IsINISection(cIniFile, cName)
Return ( aScan( _GetSectionNames(cIniFile), {|x| UPPER(x) == UPPER(cName)} ) > 0 )
*--------------------------------------------------------*
STATIC  Function IsVarINISection(cIniFile, cSecName, cName) 
Return ( aScan( _GetSection(cSecName, cIniFile), {|x| UPPER(x[1]) == UPPER(cName)} ) > 0 ) 

